package tp.mesClasses;


/**
 * La classe Cercle dfine des cercles qui sont contitus d'un centre de type Point et d'un rayon
 * @author jub
 *
 */
public class Cercle {
	/**
	 * Le centre du cercle
	 */
	private Point centre;
	/**
	 * Le rayon du cercle
	 */
	private int rayon;
	
	/**
	 * Construit un cercle unitaire de centre (0,0) et de rayon 1
	 */
	public Cercle()
	{
		this(new Point(),1);
	}
	
	/**
	 * Construit un cercle qui est une recopie d'un autre cercle
	 * @param c l'autre cercle
	 */
	public Cercle(Cercle c)
	{
		this(new Point(c.centre), c.rayon);
	}
	
	/**
	 * Construit un cercle avec les coordonnes de son centre et son rayon 
	 * @param x l'abscisse du centre
	 * @param y l'ordonne du centre
	 * @param rayon le rayon
	 */
	public Cercle(int x, int y, int rayon)
	{
		this (new Point(x,y), rayon);
	}
	
	/**
	 * Construit un cercle avec un centre et un rayon choisi
	 * @param centre le centre choisi
	 * @param rayon le rayon choisi
	 */
	public Cercle(Point centre, int rayon) {
		this.centre = centre;
		this.rayon = rayon;
	}

	/**
	 * Renvoie la circonfrence du cercle (2*PI*R)
	 * @return la circonfrence
	 */
	public double circonference()
	{
		return 2*Math.PI*this.rayon;
	}

	/**
	 * Dplace le cercle vers de nouvelles coordonnes
	 * @param x la nouvelle abscisse du centre
	 * @param y la nouvelle ordonne du centre
	 */
	public void deplacer(int x, int y)
	{
		this.centre.deplacer(x, y);
	}

	/**
	 * Permet de comparer le cercle courant et un autre cercle. 
	 * Deux cercles sont gaux, si leurs centres ont les mmes coordonnes et si les rayon sont gaux.
	 * @param c le cercle avec lequel on veut comparer le cercle courant.
	 * @return true si les cercles sont gaux et false sinon.
	 */
	public boolean estEgal(Cercle c)
	{
		return this.rayon == c.rayon && this.centre.estEgal(c.centre);
	}

	/**
	 * Permet de connatre le centre du cercle
	 * @return le centre du cercle
	 */
	public Point getCentre() {
		return centre;
	}
	
	/**
	 * Renvoie le rayon du cercle
	 * @return le rayon
	 */
	public int getRayon() {
		return rayon;
	}
	
	/**
	 * Modifie le centre du cercle
	 * @param centre le nouveau centre
	 */
	public void setCentre(Point centre) {
		this.centre = centre;
	}
	/**
	 * Modifie le rayon du cercle
	 * @param rayon le nouveau rayon
	 */
	public void setRayon(int rayon) {
		this.rayon = rayon;
	}
	@Override
	public String toString() {
		return "Cercle [centre=" + centre + ", rayon=" + rayon + "]";
	}

	/**
	 * Translate le cercle d'une quotit choisie
	 * @param dx le dplacement en abscisse
	 * @param dy le dplacement en ordonne
	 */
	public void translater(int dx, int dy)
	{
		this.centre.translater(dx, dy);
	}
	
}
