/**
 * 
 */
package tp.mesClasses;




/**
 * Cette classe dfinit l'objet <code>CompteBancaire</code>. Cette classe
 * dcrit (sommairement) un compte bancaire. On mmorise, le titulaire du compte
 * (une <code>Personne</code>), le solde du compte, son numro (unique). Ce
 * compte peut tre crdit et dbit. On mmorise en constante, le taux des
 * intrts.
 * 
 * @version 30 Janvier 2001
 * @author Remm Jean-Francois
 */

public class CompteBancaire {

	/**
	 * Le numero de compte
	 */
	private int num;

	/**
	 * pour avoir le nombre de comptes crees
	 */
	private static int nbCompte = 0;

	/**
	 * Le taux des intrts
	 */
	private final static double interet = 1.025;

	/**
	 * Le titulaire
	 */
	private Personne titulaire;

	/**
	 * Le solde du compte
	 */
	private double solde;

	/**
	 * Alloue un nouveau <code>CompteBancaire</code> initialis 
	 * <code>depotIni</code> F
	 * 
	 * @param titulaire
	 *            le titulaire du compte
	 * @param depotIni
	 *            le solde initial du compte
	 */
	public CompteBancaire(Personne titulaire, double depotIni) {
		this.titulaire = titulaire;
		this.solde = depotIni;
		this.num = ++CompteBancaire.nbCompte;
	}

	/**
	 * Alloue un nouveau <code>CompteBancaire</code> initialis  0.0 F. Ce
	 * constructeur effectue un chainage de constructeur de l'autre constructeur
	 * 
	 * @param titulaire
	 *            le titulaire du compte
	 * 
	 */
	public CompteBancaire(Personne titulaire) {
		this(titulaire, 0.0);
	}

	/**
	 * Renvoie le nombre de <code>CompteBancaire</code> crs
	 * 
	 */
	public static int getNbCompte() {
		return (CompteBancaire.nbCompte);
	}

	/**
	 * Crdite les intrts annuels sur le <code>CompteBancaire</code>
	 * courant.
	 * 
	 */
	public void crediterInteret() {
		this.solde *= CompteBancaire.interet;
	}

	/**
	 * Crdite le <code>CompteBancaire</code> de <code>val</code> F.
	 * 
	 * @param val
	 *            la somme  crditer
	 * 
	 */
	public void crediter(double val) {
		this.solde = this.solde + val;
	}

	/**
	 * Dbite le <code>CompteBancaire</code> de <code>val</code> F.
	 * 
	 * @param val
	 *            la somme  dbiter
	 * 
	 */
	public void debiter(double val) {
		this.solde = this.solde - val;
	}

	/**
	 * Renvoie le solde du <code>CompteBancaire</code> courant.
	 */
	public double getSolde() {
		return (this.solde);
	}

	/**
	 * Renvoie un boolen (<code>true</code> ou <code>false</code>).
	 * <code>true</code> si le solde du compte courant (auquel j'applique la
	 * mthode) est positif, <code>false</code> dans le cas contraire .
	 */

	public boolean estPositif() {
		return (this.solde > 0);
	}

	/**
	 * Renvoie un boolen (<code>true</code> ou <code>false</code>)
	 * <code>true</code> si le solde du compte courant (auquel j'applique la
	 * mthode) est plus grand que le solde de <code>autreCompte</code>,
	 * <code>false</code> dans le cas contraire .
	 * 
	 * @param autreCompte
	 *            l'autre compte bancaire
	 * 
	 */
	public boolean soldeSuperieur(CompteBancaire autreCompte) {
		return (this.solde > autreCompte.solde);
	}

	/**
	 * Renvoie un boolen (<code>true</code> ou <code>false</code>)
	 * <code>true</code> si le solde du <code>compte1</code> est plus grand
	 * que le solde de <code>compte2</code>, <code>false</code> dans le cas
	 * contraire .
	 * 
	 * on fera appel  la mthode <b>non statique</b> de comparaison de soldes
	 * de cette classe.
	 * 
	 * @param compte1
	 *            un compte bancaire
	 * @param compte2
	 *            un autre compte bancaire
	 */
	public static boolean soldeSuperieur(CompteBancaire compte1,
			CompteBancaire compte2) {
		return (compte1.soldeSuperieur(compte2));
	}

	/**
	 * Renvoie la <code>Personne</code> titulaire du compte
	 */
	public Personne getTitulaire() {
		return (this.titulaire);
	}

	/**
	 * Renvoie le nom (<code>String</code>) du titulaire du compte
	 */
	public String getNom() {
		return (this.titulaire.getNom());
	}

	/**
	 * Compare l'ge de deux titulaires (en utilisant la mthode
	 * <code>plusAgee</code> de la classe <code>Personne</code>)
	 * 
	 * @param autreCompte
	 *            un autre compte bancaire
	 * 
	 */
	public boolean titulairePlusAge(CompteBancaire autreCompte) {
		Personne p1 = this.getTitulaire();
		Personne p2 = autreCompte.getTitulaire();

		return (p1.plusAgee(p2));
	}

	/**
	 * Compare l'ge de deux titulaires (en utilisant la mthode
	 * <code>plusAgee</code> de la classe <code>Personne</code>)
	 * 
	 * @param compte1
	 *            un compte bancaire
	 * @param compte2
	 *            un autre compte bancaire
	 */
	public static boolean titulairePlusAge(CompteBancaire compte1,
			CompteBancaire compte2) {
		Personne p1 = compte1.getTitulaire();
		Personne p2 = compte2.getTitulaire();

		return (p1.plusAgee(p2));
	}

	/**
	 * Renvoie une chane de caractres qui dcrit le
	 * <code>CompteBancaire</code> courant (utilis de manire implicite
	 * lorsque l'on fait <code>System.out.println(unCompteBancaire)</code>)
	 */
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		StringBuffer temp;
		temp = new StringBuffer();
		temp.append("Compte de ");
		temp.append(this.titulaire);
		temp.append(" solde : ");
		temp.append(this.solde);
		temp.append(" numero : ");
		temp.append(this.num);
		temp.append(" nombre total de compte : ");
		temp.append(nbCompte);
		return (temp.toString());
	}
}