package tp.mesClasses;

/**
 * Un etudiant est caractris par son numro, son nom et ses notes.
 * @author jub
 *
 */
public class Etudiant {
	private int numero;
	private String nom;
	private Notes notes;


	/**
	 * Permet de construire un tudiant qui est une recopie d'un autre tudiant
	 * @param autre l'tudiant recopi
	 */
	public Etudiant(Etudiant autre)
	{
		this(autre.numero, new String(autre.nom), new Notes(autre.notes));
	}
	
	/**
	 * Permet de construire un tudiant en connassant son numro, son nom et ses notes
	 * @param numero le numro de l'tudiant
	 * @param nom le nom de l'tudiant
	 * @param notes les notes de l'tudiant
	 */
	public Etudiant(int numero, String nom, Notes notes) {
		this.numero = numero;
		this.nom = nom;
		this.notes = notes;
	}


	/**
	 * Permet de comparer deux tudiants.
	 * Ils sont gaux, si ils ont le mme numro, le mme nom et les mmes notes
	 * @param autre un autre tudiant
	 * @return true si les tudiants sont identiques et false sinon
	 */
	public boolean estEgal(Etudiant autre)
	{
		return this.nom.equals(autre.nom) && this.numero==autre.numero && this.notes.estEgal(autre.notes);
	}

	/**
	 * Permet de connatre la moyenne
	 * @return la moyenne des deux ue
	 */
	public double getMoyenne()
	{
		return this.notes.getMoyenne();
	}


	/**
	 * Permet de connatre le nom de l'tudiant
	 * @return le nom de l'tudiant
	 */
	public String getNom() {
		return nom;
	}


	/**
	 * Permet d'obtenir un tableau de notes avec en premire position, celle de l'ue1 et en deuxime position celle de l'ue2.
	 * @return le tableau de notes conteant la note de l'ue1 et la note de l'ue2
	 */
	public double[] getNotes()
	{
		double[] res = new double[2];
		res[0]=this.notes.getUe1();
		res[1]=this.notes.getUe2();
		return res;
	}

	/**
	 * Permet de connatre le numro de l'tudiant
	 * @return le numro de l'tudiant
	 */
	public int getNumero() {
		return numero;
	}

	
	/**
	 * Permet de connatre la note de l'ue1
	 * @return la note de l'ue1
	 */
	public double getUe1()
	{
		return this.notes.getUe1();
	}
	
	/**
	 * Permet de connatre la note de l'ue2
	 * @return la note de l'ue2
	 */
	public double getUe2()
	{
		return this.notes.getUe2();
	}
	
	/**
	 * Permet de savoir si l'tudiant  la semestre
	 * @return true si le semestre est obtenu et false sinon
	 */
	public boolean semestreOk()
	{
		return this.notes.semestreOk();
	}
	
	/**
	 * Permet de modifier le nom de l'tudiant
	 * @param nom le nouveau nom de l'tudiant
	 */
	public void setNom(String nom) {
		this.nom = nom;
	}

	/**
	 * Permet de modifier la note de l'ue1
	 * @param note la nouvelle note
	 */
	public void setUe1(double note)
	{
		this.notes.setUe1(note);
	}
	
	/**
	 * Permet de modifier la note de l'ue2
	 * @param note la nouvelle note
	 */
	public void setUe2(double note)
	{
		this.notes.setUe2(note);
	}
	@Override
	public String toString() {
		return "Etudiant [numero=" + numero + ", nom=" + nom + ", notes="
		+ notes + "]";
	}

}
